/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JLogFactory.java 572 2006-06-04 21:23:27Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.log;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.objectweb.easybeans.i18n.I18n;

/**
 * This factory delegates to commons logging factory the creation of a logger.
 * Then, this logger is wrapped into an EasyBeans logger.
 * @author Florent Benoit
 */
public final class JLogFactory {

    /**
     * Utility class, no public constructor.
     */
    private JLogFactory() {

    }

    /**
     * Factory method used to return a logger.
     * @param clazz a class used as a key for the logger
     * @return an EasyBeans logger.
     */
    public static JLog getLog(final Class clazz) {
        Log log = LogFactory.getLog(clazz);
        return new CommonsLoggerImpl(log, I18n.getInstance(clazz));
    }
}
