/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: BeanInfo.java 871 2006-07-13 14:23:56Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.container.info;

import java.util.Map;

import javax.ejb.ApplicationException;
import javax.ejb.TransactionManagementType;

import org.objectweb.easybeans.api.bean.IBeanInfo;

import static javax.ejb.TransactionManagementType.CONTAINER;

/**
 * This class contains description for a bean.
 * It is used at the runtime.
 * @author Florent Benoit
 */
public class BeanInfo implements IBeanInfo {
    /**
     * Management type for the bean.
     */
    private TransactionManagementType transactionManagementType = CONTAINER;

    /**
     * List of application exceptions used on this ejb-jar.
     */
    private Map<String, ApplicationException> applicationExceptions = null;


    /**
     * Gets the list of application exceptions defined on this ejb jar metadata.
     * @return the list of application exceptions defined on this ejb jar metadata.
     */
    public Map<String, ApplicationException> getApplicationExceptions() {
        return applicationExceptions;
    }

    /**
     * Sets the list of application exceptions defined on this ejb jar metadata.
     * @param applicationExceptions the list of application exceptions defined on this ejb jar metadata.
     */
    public void setApplicationExceptions(final Map<String, ApplicationException> applicationExceptions) {
        this.applicationExceptions = applicationExceptions;
    }

    /**
     * Gets the type of transaction for the given bean.
     * @return transaction management type.
     */
    public TransactionManagementType getTransactionManagementType() {
        return transactionManagementType;
    }

    /**
     * Sets the type of transaction for the given bean.
     * @param transactionManagementType transaction management type.
     */
    public void setTransactionManagementType(final TransactionManagementType transactionManagementType) {
        this.transactionManagementType = transactionManagementType;
    }


}
