/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ENCManager.java 399 2006-04-24 16:38:14Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.objectweb.easybeans.naming.interceptors;

import org.objectweb.easybeans.log.JLog;
import org.objectweb.easybeans.log.JLogFactory;

/**
 * Detects the server type and return the correct interceptor to use depending of the application server.
 * It could be EasyBeans, JOnAS or Tomcat.
 * @author Florent Benoit
 */
public final class ENCManager {

    /**
     * Logger.
     */
    private static JLog logger = JLogFactory.getLog(ENCManager.class);

    /**
     * Class used for the interceptor.
     */
    private static Class encInterceptor = null;

    /**
     * No public constructor (utility class).
     */
    private ENCManager() {

    }

    /**
     * @return the class to use depending of the application server.
     */
    public static Class getInterceptorClass() {
        if (encInterceptor == null) {
            ClassLoader loader = Thread.currentThread().getContextClassLoader();

            // try to load JOnAS class.
            try {
                loader.loadClass(JOnASENCInterceptor.JONAS_NAMING_MANAGER_CLASS);
                encInterceptor = JOnASENCInterceptor.class;
                logger.info("Detecting JOnAS : using JOnAS ENC for the naming.");
            } catch (ClassNotFoundException e) {
                // not found, try with Tomcat
                try {
                    loader.loadClass(TomcatENCInterceptor.TOMCAT_NAMING_CLASS);
                    encInterceptor = TomcatENCInterceptor.class;
                    logger.info("Detecting Tomcat : using Tomcat ENC for the naming.");
                } catch (ClassNotFoundException e1) {
                    // Not found, use EZB.
                    encInterceptor = EZBENCInterceptor.class;
                    logger.debug("Using EasyBeans ENC for the naming.");
                }
            }

        }
        return encInterceptor;
    }
}
